"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _mocha = require("mocha");
var _chai = require("chai");
var _react = require("@testing-library/react");
var _react2 = require("react");
var _sinon = _interopRequireDefault(require("sinon"));
var _index = _interopRequireDefault(require("./index"));
var _jsxRuntime = require("react/jsx-runtime");
const TestComponent = _ref => {
  let {
    handler,
    delay,
    deps,
    onCallbackChange
  } = _ref;
  const callback = (0, _index.default)(handler, delay, deps);
  (0, _react2.useEffect)(() => {
    onCallbackChange(callback);
  }, [callback]);
  return null;
};
describe('use_debounced_callback', () => {
  let clock;
  beforeEach(() => {
    clock = _sinon.default.useFakeTimers();
  });
  afterEach(() => {
    clock.restore();
  });
  context('deps change', () => {
    (0, _mocha.it)('cancels queue', () => {
      const hookCallbackRef = {
        current: null
      };
      const onCallbackChange = newCallback => {
        hookCallbackRef.current = newCallback;
      };
      const handler = _sinon.default.spy();
      const {
        rerender
      } = (0, _react.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: handler,
        delay: 100,
        deps: [1],
        onCallbackChange: onCallbackChange
      }));
      (0, _react.act)(() => {
        hookCallbackRef.current();
      });
      rerender( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: handler,
        delay: 200,
        deps: [2],
        onCallbackChange: onCallbackChange
      }));
      (0, _react.act)(() => {
        clock.tick(200);
      });
      (0, _chai.expect)(handler.called).is.false;
    });
  });
  context('handler changes', () => {
    (0, _mocha.it)('queue stays', () => {
      const hookCallbackRef = {
        current: null
      };
      const onCallbackChange = newCallback => {
        hookCallbackRef.current = newCallback;
      };
      const handler = _sinon.default.spy();
      const {
        rerender
      } = (0, _react.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: handler,
        delay: 200,
        deps: [],
        onCallbackChange: onCallbackChange
      }));
      (0, _react.act)(() => {
        hookCallbackRef.current();
      });
      const newHandler = _sinon.default.spy();
      rerender( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: newHandler,
        delay: 200,
        deps: [],
        onCallbackChange: onCallbackChange
      }));
      (0, _react.act)(() => {
        clock.tick(200);
      });
      (0, _chai.expect)(newHandler.called, 'new handler got called').is.true;
      (0, _chai.expect)(handler.called, 'old handler did not get called').is.false;
    });
    (0, _mocha.it)('returns same callback', () => {
      const hookCallbackRef = {
        current: null
      };
      const onCallbackChange = newCallback => {
        hookCallbackRef.current = newCallback;
      };
      const handler = _sinon.default.spy();
      const {
        rerender
      } = (0, _react.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: handler,
        delay: 200,
        deps: [],
        onCallbackChange: onCallbackChange
      }));
      const initialHookCallback = hookCallbackRef.current;
      const newHandler = _sinon.default.spy();
      rerender( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        handler: newHandler,
        delay: 200,
        deps: [],
        onCallbackChange: onCallbackChange
      }));
      (0, _chai.expect)(initialHookCallback).equal(hookCallbackRef.current);
    });
  });
  (0, _mocha.it)('calls handler debounced', () => {
    const hookCallbackRef = {
      current: null
    };
    const onCallbackChange = newCallback => {
      hookCallbackRef.current = newCallback;
    };
    const handler = _sinon.default.spy();
    (0, _react.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
      handler: handler,
      delay: 100,
      deps: [],
      onCallbackChange: onCallbackChange
    }));
    (0, _react.act)(() => {
      hookCallbackRef.current();
    });
    (0, _react.act)(() => {
      clock.tick(70);
    });
    (0, _react.act)(() => {
      hookCallbackRef.current();
    });
    (0, _react.act)(() => {
      clock.tick(100);
    });
    (0, _react.act)(() => {
      hookCallbackRef.current();
    });
    (0, _react.act)(() => {
      clock.tick(100);
    });
    (0, _chai.expect)(handler.calledTwice).is.true;
  });
});