"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEventListener = void 0;
var _react = require("react");
/**
 * @function
 * @param {React.RefObject} ref
 * @param {string} type EventListener type
 * @param {function} handler Handler function
 * @param {Boolean} passive EventListener option passive
 * @param {Boolean} capture EventListener option capture
 * @param {Boolean} once EventListener option once
 */
const useEventListener = function (ref, type, handler) {
  let {
    passive,
    capture,
    once
  } = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {
    passive: true
  };
  const handlerRef = (0, _react.useRef)(null);
  handlerRef.current = handler;
  (0, _react.useEffect)(() => {
    const node = ref.current;
    if (!node) return;
    const listener = function () {
      return handlerRef.current(...arguments);
    };
    const options = {
      passive,
      capture,
      once
    };
    node.addEventListener(type, listener, options);
    return () => {
      node.removeEventListener(type, listener, options);
    };
  }, [type, ref.current, passive, capture, once]);
};
exports.useEventListener = useEventListener;